import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class DialogFooter extends StatelessWidget {
  final VoidCallback onCancel;
  final VoidCallback? onConfirm;
  final bool isConfirmEnabled;

  const DialogFooter({
    Key? key,
    required this.onCancel,
    required this.onConfirm,
    required this.isConfirmEnabled,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(
        border: Border(
          top: BorderSide(
            color: ColorsManager.greyColor,
          ),
        ),
      ),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          _buildFooterButton(
            context,
            'Cancel',
            onCancel,
            width: isConfirmEnabled ? 299 : 179,
          ),
          if (isConfirmEnabled)
            Row(
              children: [
                Container(width: 1, height: 50, color: ColorsManager.greyColor),
                _buildFooterButton(
                  context,
                  'Confirm',
                  onConfirm,
                  width: 299,
                ),
              ],
            ),
        ],
      ),
    );
  }

  Widget _buildFooterButton(
    BuildContext context,
    String text,
    VoidCallback? onTap, {
    required double width,
  }) {
    return GestureDetector(
      onTap: onTap,
      child: SizedBox(
        height: 50,
        width: width,
        child: Center(
          child: Text(
            text,
            style: Theme.of(context).textTheme.bodyMedium!.copyWith(
                  color: text == 'Confirm'
                      ? ColorsManager.primaryColorWithOpacity
                      : ColorsManager.textGray,
                ),
          ),
        ),
      ),
    );
  }
}
